@@ -51,8 +51,14 @@ class KNativeKafkaConsumer(threading.Thread):
             if 'KAFKA_NET_TLS_KEY' not in os.environ:
                 raise ValueError( 'TLS Key is required!')
             self.ssl_cafile=os.environ['KAFKA_NET_TLS_CA_CERT']
+            print(os.environ['KAFKA_NET_TLS_CA_CERT'])
+            self.logger.info(os.environ['KAFKA_NET_TLS_CA_CERT'])
             self.ssl_certfile=os.environ['KAFKA_NET_TLS_CERT']
+            print(self.ssl_certfile)
+            self.logger.info(self.ssl_certfile)
             self.ssl_keyfile=os.environ['KAFKA_NET_TLS_KEY']
+            print(self.ssl_keyfile)
+            self.logger.info(self.ssl_keyfile)
             print("Inside if")
             self.logger.info("Inside if")
         else:
@@ -76,8 +82,11 @@ class KNativeKafkaConsumer(threading.Thread):
                           enable_auto_commit=False)
                             #auto_commit_interval_ms=1000)
         except KafkaError as e:
+            
+            print("Inexception")
+            print("Exception while creating consumer - {}".format(e))
             self.logger.error(f'Kafka Error {e}')
-            raise Exception(f'Kafka Error {e}')
+            
  
         print("KafkaConsumer Creation Success!")
     def getMessage(self) -> str:
