@@ -33,8 +33,6 @@ class KNativeKafkaProducer(threading.Thread):
 
         self.bootstrap_servers=os.getenv('KAFKA_BOOTSTRAP_SERVERS',default='localhost:9092')
         
-        self.logger.info(self.bootstrap_servers)
-        
         is_tls_enable=os.getenv('KAFKA_NET_TLS_ENABLE',default='False')
         self.logger.info(is_tls_enable)
         if is_tls_enable == 'True':
@@ -61,7 +59,7 @@ class KNativeKafkaProducer(threading.Thread):
                         ssl_keyfile=self.ssl_keyfile
                         )
 
-    def send_binary_data(self, data:str):
+    def send_binary_data(self, data:str, key:str):
         """
         Sends the binary data to Kafka topic using the send()
         Parameters
@@ -71,8 +69,8 @@ class KNativeKafkaProducer(threading.Thread):
 
         """
         try:
-            self.logger.info('Sending the data {} to topic {}'.format(data, self.topic))
-            self.producer.send(self.topic, data)
+            self.logger.info('Sending the data {} to topic {} with key {}'.format(data, self.topic,key))
+            self.producer.send(self.topic, data, key)
             self.producer.flush(30)
         except KafkaError as e:
             self.logger.error(f'Kafka Error {e}')
